@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Supports the Planar Langmuir Probe (PLP) onboard the Communication
+"""Module for the C/NOFS PLP instrument.
+
+Supports the Planar Langmuir Probe (PLP) onboard the Communication
 and Navigation Outage Forecasting System (C/NOFS) satellite. Downloads
 data from the NASA Coordinated Data Analysis Web (CDAWeb).
 
@@ -58,11 +60,11 @@ import datetime as dt
 import functools
 import numpy as np
 
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
-from pysatNASA.instruments.methods import cnofs as mm_cnofs
 from pysatNASA.instruments.methods import cdaweb as cdw
+from pysatNASA.instruments.methods import cnofs as mm_cnofs
 
 # ----------------------------------------------------------------------------
 # Instrument attributes
@@ -82,7 +84,7 @@ _test_dates = {'': {'': dt.datetime(2009, 1, 1)}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -96,7 +98,7 @@ def init(self):
 
 
 def clean(self):
-    """Routine to return C/NOFS PLP data cleaned to the specified level
+    """Clean C/NOFS PLP data to the specified level.
 
     Note
     ----
@@ -106,7 +108,7 @@ def clean(self):
 
     for key in self.data.columns:
         if key != 'Epoch':
-            fill = self.meta[key, self.meta.labels.fill_val][0]
+            fill = self.meta[key, self.meta.labels.fill_val]
             idx, = np.where(self[key] == fill)
             self[idx, key] = np.nan
     return
