@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Supports the Langmuir Probe (LANG) instrument on
-Dynamics Explorer 2 (DE2).
+"""Module for the DE2 LANG instrument.
+
+Supports the Langmuir Probe (LANG) instrument on Dynamics Explorer 2 (DE2).
 
 From CDAWeb:
 
@@ -27,8 +28,8 @@ or correct the inflight processed data. Time resolution was 0.5 seconds.
 References
 ----------
 J. P. Krehbiel, L. H. Brace, R. F. Theis, W. H. Pinkus, and R. B. Kaplan,
-The Dynamics Explorer 2 Langmuir Probe (LANG), Space Sci. Instrum., v. 5, n. 4,
-p. 493, 1981.
+"The Dynamics Explorer 2 Langmuir Probe (LANG)", Space Sci. Instrum., 5,
+493-502, 1981.
 
 Properties
 ----------
@@ -47,21 +48,17 @@ Warnings
 - Currently no cleaning routine.
 
 
-Authors
--------
-J. Klenzing
-
 """
 
 import datetime as dt
 import functools
 import warnings
 
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
-from pysatNASA.instruments.methods import de2 as mm_de2
 from pysatNASA.instruments.methods import cdaweb as cdw
+from pysatNASA.instruments.methods import de2 as mm_de2
 
 # ----------------------------------------------------------------------------
 # Instrument attributes
@@ -81,7 +78,7 @@ _test_dates = {'': {'': dt.datetime(1983, 1, 1)}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -94,7 +91,7 @@ def init(self):
 
 
 def clean(self):
-    """Routine to return DE2 LANG data cleaned to the specified level
+    """Clean DE2 LANG data to the specified level.
 
     Note
     ----
