@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Supports the Neutral Atmosphere Composition Spectrometer (NACS) instrument
+"""The DE2 NACS instrument.
+
+Supports the Neutral Atmosphere Composition Spectrometer (NACS) instrument
 on Dynamics Explorer 2 (DE2).
 
 From CDAWeb:
@@ -51,9 +53,8 @@ were lost between 12 March 1982 and 31 March 1982 when the counter overflowed.
 References
 ----------
 G. R. Carrignan, B. P. Block, J. C. Maurer,  A. E. Hedin, C. A. Reber,
-N. W. Spencer
-The neutral mass spectrometer on Dynamics Explorer B
-Space Sci. Instrum., v. 5, n. 4, p. 429, 1981.
+N. W. Spencer, "The neutral mass spectrometer on Dynamics Explorer B",
+Space Sci. Instrum., 5, 429-441, 1981.
 
 Properties
 ----------
@@ -70,21 +71,17 @@ Warnings
 --------
 - Currently no cleaning routine.
 
-Authors
--------
-J. Klenzing
-
 """
 
 import datetime as dt
 import functools
 import warnings
 
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
-from pysatNASA.instruments.methods import de2 as mm_de2
 from pysatNASA.instruments.methods import cdaweb as cdw
+from pysatNASA.instruments.methods import de2 as mm_de2
 
 # ----------------------------------------------------------------------------
 # Instrument attributes
@@ -104,7 +101,7 @@ _test_dates = {'': {'': dt.datetime(1983, 1, 1)}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -117,7 +114,7 @@ def init(self):
 
 
 def clean(self):
-    """Routine to return DE2 NACS data cleaned to the specified level
+    """Clean DE2 NACS data to the specified level.
 
     Note
     ----
