@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Supports the Wind and Temperature Spectrometer (WATS) instrument on
+"""Module for the DE2 WATS instrument.
+
+Supports the Wind and Temperature Spectrometer (WATS) instrument on
 Dynamics Explorer 2 (DE2).
 
 From CDAWeb:
@@ -48,8 +50,8 @@ about the processing done at NSSDC is given in WATS_NSSDC_PRO_DE.DOC.
 References
 ----------
 N. W. Spencer, L. E. Wharton, H. B. Niemann, A. E. Hedin, G. R. Carrignan,
-J. C. Maurer, The Dynamics Explorer Wind and Temperature Spectrometer
-Space Sci. Instrum., v. 5, n. 4, p. 417, 1981.
+J. C. Maurer, "The Dynamics Explorer Wind and Temperature Spectrometer",
+Space Sci. Instrum., 5, 417-428, 1981.
 
 Properties
 ----------
@@ -66,21 +68,17 @@ Warnings
 --------
 - Currently no cleaning routine.
 
-Authors
--------
-J. Klenzing
-
 """
 
 import datetime as dt
 import functools
 import warnings
 
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
-from pysatNASA.instruments.methods import de2 as mm_de2
 from pysatNASA.instruments.methods import cdaweb as cdw
+from pysatNASA.instruments.methods import de2 as mm_de2
 
 # ----------------------------------------------------------------------------
 # Instrument attributes
@@ -100,7 +98,7 @@ _test_dates = {'': {'': dt.datetime(1983, 1, 1)}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -113,7 +111,7 @@ def init(self):
 
 
 def clean(self):
-    """Routine to return DE2 LANG data cleaned to the specified level
+    """Clean DE2 LANG data to the specified level.
 
     Note
     ----
