@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Supports the Extreme Ultraviolet (EUV) imager onboard the Ionospheric
+"""Module for the ICON EUV instrument.
+
+Supports the Extreme Ultraviolet (EUV) imager onboard the Ionospheric
 CONnection Explorer (ICON) satellite.  Accesses local data in
 netCDF format.
 
@@ -34,19 +36,14 @@ ICON_L27_Ion_Density becomes Ion_Density.  To retain the original names, use
     euv = pysat.Instrument(platform='icon', name='euv',
                            keep_original_names=True)
 
-Authors
----------
-Jeff Klenzing, Mar 17, 2018, Goddard Space Flight Center
-Russell Stoneback, Mar 23, 2018, University of Texas at Dallas
-
 """
 
 import datetime as dt
 import functools
 
 import pysat
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
 from pysatNASA.instruments.methods import cdaweb as cdw
 from pysatNASA.instruments.methods import icon as mm_icon
@@ -71,7 +68,7 @@ _test_dates = {'': {'': dt.datetime(2020, 1, 1)}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -91,7 +88,7 @@ def init(self):
 
 
 def preprocess(self, keep_original_names=False):
-    """Adjusts epoch timestamps to datetimes and removes variable preambles.
+    """Adjust epoch timestamps to datetimes and remove variable preambles.
 
     Parameters
     ----------
@@ -108,7 +105,7 @@ def preprocess(self, keep_original_names=False):
 
 
 def clean(self):
-    """Provides data cleaning based upon clean_level.
+    """Clean ICON EUV data to the specified level.
 
     Note
     ----
@@ -156,7 +153,7 @@ list_remote_files = functools.partial(cdw.list_remote_files,
 
 
 def load(fnames, tag=None, inst_id=None, keep_original_names=False):
-    """Loads ICON EUV data using pysat into pandas.
+    """Load ICON EUV data into `xarray.Dataset` object and `pysat.Meta` objects.
 
     This routine is called as needed by pysat. It is not intended
     for direct user interaction.
