@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
+"""Module for the ICON IVM instrument.
 
-"""Supports the Ion Velocity Meter (IVM)
-onboard the Ionospheric Connections (ICON) Explorer.
+Supports the Ion Velocity Meter (IVM) onboard the Ionospheric Connections
+(ICON) Explorer.
 
 Properties
 ----------
@@ -41,8 +42,8 @@ import functools
 import numpy as np
 
 import pysat
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
 from pysatNASA.instruments.methods import cdaweb as cdw
 from pysatNASA.instruments.methods import icon as mm_icon
@@ -61,7 +62,7 @@ tags = {'': 'Level 2 public geophysical data'}
 # is not available as of Jun 26 2020, as this mode has not yet been engaged.
 # Bypassing tests and warning checks via the password_req flag
 inst_ids = {'a': [''], 'b': ['']}
-
+multi_file_day = True
 
 # ----------------------------------------------------------------------------
 # Instrument test attributes
@@ -76,7 +77,7 @@ _password_req = {'b': {kk: True for kk in tags.keys()}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -96,7 +97,7 @@ def init(self):
 
 
 def preprocess(self, keep_original_names=False):
-    """Removes variable preambles.
+    """Remove variable preambles.
 
     Parameters
     ----------
@@ -112,7 +113,7 @@ def preprocess(self, keep_original_names=False):
 
 
 def clean(self):
-    """Provides data cleaning based upon clean_level.
+    """Clean ICON IVM data to the specified level.
 
     Note
     ----
@@ -123,11 +124,40 @@ def clean(self):
     # IVM variable groupings
     drift_variables = ['Ion_Velocity_X', 'Ion_Velocity_Zonal',
                        'Ion_Velocity_Meridional',
-                       'Ion_Velocity_Field_Aligned']
+                       'Ion_Velocity_Field_Aligned',
+                       'Equator_Ion_Velocity_Meridional',
+                       'Equator_Ion_Velocity_Zonal',
+                       'Footpoint_Zonal_Ion_Velocity_North',
+                       'Footpoint_Zonal_Ion_Velocity_South',
+                       'Footpoint_Meridional_Ion_Velocity_North',
+                       'Footpoint_Meridional_Ion_Velocity_South',
+                       'Ion_Velocity_East', 'Ion_Velocity_North',
+                       'Ion_Velocity_Up',
+                       'Footpoint_East_Ion_Velocity_North',
+                       'Footpoint_East_Ion_Velocity_South',
+                       'Footpoint_North_Ion_Velocity_North',
+                       'Footpoint_North_Ion_Velocity_South',
+                       'Footpoint_Up_Ion_Velocity_North',
+                       'Footpoint_Up_Ion_Velocity_South']
+
     cross_drift_variables = ['Ion_Velocity_Z', 'Ion_Velocity_Y',
                              'Ion_Velocity_Zonal',
                              'Ion_Velocity_Meridional',
-                             'Ion_Velocity_Field_Aligned']
+                             'Ion_Velocity_Field_Aligned',
+                             'Equator_Ion_Velocity_Meridional',
+                             'Equator_Ion_Velocity_Zonal',
+                             'Footpoint_Zonal_Ion_Velocity_North',
+                             'Footpoint_Zonal_Ion_Velocity_South',
+                             'Footpoint_Meridional_Ion_Velocity_North',
+                             'Footpoint_Meridional_Ion_Velocity_South',
+                             'Ion_Velocity_East', 'Ion_Velocity_North',
+                             'Ion_Velocity_Up',
+                             'Footpoint_East_Ion_Velocity_North',
+                             'Footpoint_East_Ion_Velocity_South',
+                             'Footpoint_North_Ion_Velocity_North',
+                             'Footpoint_North_Ion_Velocity_South',
+                             'Footpoint_Up_Ion_Velocity_North',
+                             'Footpoint_Up_Ion_Velocity_South']
     rpa_variables = ['Ion_Temperature', 'Ion_Density',
                      'Fractional_Ion_Density_H',
                      'Fractional_Ion_Density_O']
@@ -187,7 +217,7 @@ list_remote_files = functools.partial(cdw.list_remote_files,
 
 
 def load(fnames, tag=None, inst_id=None, keep_original_names=False):
-    """Loads ICON IVM data using pysat into pandas.
+    """Load ICON IVM data into `pandas.DataFrame` and `pysat.Meta` objects.
 
     This routine is called as needed by pysat. It is not intended
     for direct user interaction.
