@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Supports the Floating Potential Measurement Unit
+"""Module for the ISS FPMU instrument.
+
+Supports the Floating Potential Measurement Unit
 (FPMU) instrument onboard the International Space
 Station (ISS). Downloads data from the NASA
 Coordinated Data Analysis Web (CDAWeb).
@@ -26,8 +28,8 @@ import datetime as dt
 import functools
 import numpy as np
 
-from pysat import logger
 from pysat.instruments.methods import general as mm_gen
+from pysat import logger
 
 from pysatNASA.instruments.methods import cdaweb as cdw
 
@@ -49,7 +51,7 @@ _test_dates = {'': {'': dt.datetime(2017, 10, 1)}}
 
 
 def init(self):
-    """Initializes the Instrument object with instrument specific values.
+    """Initialize the Instrument object with instrument specific values.
 
     Runs once upon instantiation.
 
@@ -78,7 +80,7 @@ def init(self):
 
 
 def clean(self):
-    """Return FPMU data cleaned to the specified level.
+    """Clean ISS FPMU data to the specified level.
 
     Note
     ----
@@ -89,8 +91,11 @@ def clean(self):
 
     """
 
-    self.data.replace(-999., np.nan, inplace=True)  # Te
-    self.data.replace(-9.9999998e+30, np.nan, inplace=True)  # Ni
+    # Replace Te data fill
+    self.data.replace(-999., np.nan, inplace=True)
+
+    # Replace Ne data fill
+    self.data.replace(-9.9999998e+30, np.nan, inplace=True)
 
     return
 
